/* global describe it */

require('should');
const validator = require('../lib/truncate-paragraph/validator');
const truncate = require('../lib/truncate-paragraph');


describe('#truncate-paragraph', () => {

    describe('#validator', () => {
        it('should return correctly', () => {
            validator('ada', 'aja').should.equal(false);
            validator('ada', ' aja').should.equal(true);
            validator('ada-', 'aja').should.equal(true);
        });
    })
    
    it('should return correctly - 1', () => {
        const [head, tail] = truncate('12345 12', 5);

        // console.log([head, tail]);

        head.should.be.ok();
        tail.should.be.ok();
    });

    it('should return correctly - 2', () => {
        truncate('12345 123', 5)[0].should.equal('12345');
        truncate('12345 123', 5)[1].should.equal('123');

        truncate('12345 789', 7)[0].should.equal('12345', 'head 12345 789, 7');
        truncate('12345 789', 7)[0].length.should.be.belowOrEqual(7, 'head length 12345 789, 7');
        truncate('12345 789', 7)[1].should.equal('789', 'tail 12345 789, 7');

        truncate('12345 789 12345678', 10)[0].should.equal('12345 789', 'head 12345 789 12345678, 10');
        truncate('12345 789 12345678', 10)[0].length.should.be.belowOrEqual(10, 'head length 12345 789 12345678, 10');
        truncate('12345 789 12345678', 10)[1].should.equal('12345678', 'tail 12345 789 12345678, 10');

        truncate('12345-6789', 7)[0].should.equal('12345-');
        truncate('12345-6789', 7)[1].should.equal('6789');

        // truncate('Downline anda:\n#28 ABC CELL. Saldo: Rp. 4.500.000\n#35 BAYARKILAT. Saldo: Rp. 1.926.500\n#47 COBA1907011835. Saldo: Rp. 0\n#58 COBADARIMESSAGING. Saldo: Rp. 0\n#59 COBADARIMESSAGING1. Saldo: Rp. 0\n#60 COBADARIMESSAGING2. Saldo: Rp. 0\n#61 COBADARIMESSAGING3. Saldo: Rp. 0\n#62 COBADARIMESSAGING4. Saldo: Rp. 0\n#63 COBADARIMESSAGING5. Saldo: Rp. 0\n#48 COBADEFAULTMARKUP. Saldo: Rp. 0\n#49 COBADEFMARKUP2. Saldo: Rp. 0\n#50 COBADEFMARKUP3. Saldo: Rp. 0\n#51 COBADEFMARKUP4. Saldo: Rp. 0\n#52 COBADEFMARKUP5. Saldo: Rp. 0\n#53 COBADEFMARKUP6. Saldo: Rp. 0\n#54 COBADEFMARKUP7. Saldo: Rp. 0\n#55 COBADEFMARKUP8. Saldo: Rp. 0\n#56 COBADEFMARKUP9. Saldo: Rp. 0\n#57 COBADEFMARKUP99. Saldo: Rp. 0\n#36 DEMO. Saldo: Rp. 0\n#38 DUMMY. Saldo: Rp. 4.994.500\n#46 DUMMY13410. Saldo: Rp. 0\n#45 EVO. Saldo: Rp. 170.000\n#40 GIRASTEKDEV. Saldo: Rp. 1.000.000\n#39 HIKE. Saldo: Rp. 8.100.025\n#37 HOKISTORE. Saldo: Rp. 1.542.000\n#41 JPUDEV. Saldo: Rp. 1.000.000\n#30 KISELDEV. Saldo: Rp. 4.789.500\n#44 MELON SANDBOX. Saldo: Rp. 0\n#34 PASARSELON. Saldo: Rp. 0\n#23 PM0. Saldo: Rp. 664.700\n#27 RELOAD97. Saldo: Rp. 136.683.515\n#21 STORE2. Saldo: Rp. 664.700\n#2 TEST. Saldo: Rp. 664.700\n#3 TEST1. Saldo: Rp. 664.700\n#17 TEST10. Saldo: Rp. 664.700\n#8 TEST4. Saldo: Rp. 664.700\n#10 TEST5. Saldo: Rp. 664.700\n#12 TEST6. Saldo: Rp. 80.664.700\n#13 TEST7. Saldo: Rp. 664.700\n#14 TEST8. Saldo: Rp. 664.700\n#19 TOKOBAGUS. Saldo: Rp. 664.700\n#20 TOKOCUMI. Saldo: Rp. 664.700\n#43 VERSA. Saldo: Rp. 16.780.480\n#42 VERSA DEV. Saldo: Rp. 445.000\n#22 ZSTORE1. Saldo: Rp. 664.700\n#66 coba0717. Saldo: Rp. 0\n#67 coba0826. Saldo: Rp. 0\n#85 coba08261000. Saldo: Rp. 0\n#75 coba08261305. Saldo: Rp. 0\n#76 coba08261401. Saldo: Rp. 0\n#78 coba08261448. Saldo: Rp. 0\n#79 coba08261449m25. Saldo: Rp. 0\n#87 coba08261518. Saldo: Rp. 0\n#88 coba08261519. Saldo: Rp. 0\n#89 coba08261520. Saldo: Rp. 0\n#90 coba08261924. Saldo: Rp. 0\n#92 coba08261925. Saldo: Rp. 0\n#95 coba08261933. Saldo: Rp. 0\n#96 coba08261937. Saldo: Rp. 0\n#97 coba08261939. Saldo: Rp. 0\n#98 coba08261944. Saldo: Rp. 0\n#99 coba08261945. Saldo: Rp. 0\n#100 coba08261947. Saldo: Rp. 0\n#101 coba08262003. Saldo: Rp. 0\n#102 coba082620031. Saldo: Rp. 0\n#80 coba0826cekdefm. Saldo: Rp. 0\n#77 coba0826markup25. Saldo: Rp. 0\n#82 coba0826ms. Saldo: Rp. 0\n#81 coba0826overm. Saldo: Rp. 0\n#86 coba0826tele. Saldo: Rp. 0\n#64 cumi678. Saldo: Rp. 518.215","head":"Downline anda:\n#28 ABC CELL. Saldo: Rp. 4.500.000\n#35 BAYARKILAT. Saldo: Rp. 1.926.500\n#47 COBA1907011835. Saldo', 140)[0].should.equal('ad')
    })
});
